pub struct ExperimentDescription {
pub optics: Optics,
pub illumination: Illumination,
pub optical_background: Option<Vec<f64>>,
}Expand description
Concrete optical experiment description used to compile an image-plane model.
Fields
optics: Opticsillumination: Illuminationoptical_background: Option<Vec<f64>>Optional optical intensity background, broadcast or stored per frame.
Implementations
Sourceimpl ExperimentDescription
impl ExperimentDescription
pub fn new(optics: Optics, illumination: Illumination) -> Self
pub fn with_optical_background(self, background: Vec<f64>) -> Self
pub fn compile( &self, image_shape: (usize, usize), reconstruction_shape: ReconstructionShape, ) -> Result<ImagePlaneModel>
pub fn validate(&self) -> Result<()>