pub struct SimulationConfiguration {
pub format_version: u32,
pub true_experiment: ExperimentDescription,
pub reconstruction_experiment: ExperimentDescription,
pub image_shape: (usize, usize),
pub reconstruction_shape: (usize, usize),
pub compiled_models: CompiledModelPair,
pub camera: Option<CameraModel>,
pub illumination_acquisition_errors: Option<IlluminationAcquisitionErrors>,
pub random_seed: u64,
}Expand description
Complete, versioned configuration for simulation and reconstruction.
Fields
format_version: u32true_experiment: ExperimentDescriptionreconstruction_experiment: ExperimentDescriptionimage_shape: (usize, usize)reconstruction_shape: (usize, usize)compiled_models: CompiledModelPaircamera: Option<CameraModel>illumination_acquisition_errors: Option<IlluminationAcquisitionErrors>random_seed: u64Implementations
Sourceimpl SimulationConfiguration
impl SimulationConfiguration
pub fn new( true_experiment: ExperimentDescription, reconstruction_experiment: ExperimentDescription, image_shape: (usize, usize), reconstruction_shape: ReconstructionShape, ) -> Result<Self>
pub fn with_camera(self, camera: CameraModel) -> Result<Self>
pub fn with_illumination_acquisition_errors( self, errors: IlluminationAcquisitionErrors, ) -> Result<Self>
pub fn with_random_seed(self, random_seed: u64) -> Self
Sourcepub fn reconstruction_model_for_counts(&self) -> Result<ImagePlaneModel>
pub fn reconstruction_model_for_counts(&self) -> Result<ImagePlaneModel>
Returns the assumed model with known linear camera response compiled in.
The serialized compiled_models.reconstruction_model remains the
strict optical model. Use this helper when constructing a
reconstruction problem from detector counts loaded through a saved
configuration.
pub fn validate(&self) -> Result<()>
pub fn save(&self, path: impl AsRef<Path>) -> Result<()>
pub fn load(path: impl AsRef<Path>) -> Result<Self>